=== modified file 'NEWS'
--- NEWS	2010-09-15 10:10:22 +0000
+++ NEWS	2010-09-17 04:21:12 +0000
@@ -299,6 +299,10 @@
 * Rearrange thread leak detection code to eliminate global state and make it
   possible to extend the reporting. (Marting [gz], #633462)
 
+* Suppress the "maximum recursion depth exceeded in __subclasscheck__"
+  warning on stderr emitted during ``test_dict_deepnested`` in
+  ``bzrlib/tests/test__bencode.py``.  (Andrew Bennetts)
+
 * The test suite now simply holds log files in memory, rather than writing them
   out to disk and then reading them back in and deleting them.
   (Andrew Bennetts)

=== modified file 'bzrlib/tests/test__bencode.py'
--- bzrlib/tests/test__bencode.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test__bencode.py	2010-09-17 04:21:12 +0000
@@ -16,6 +16,9 @@
 
 """Tests for bencode structured encoding"""
 
+import sys
+from cStringIO import StringIO
+
 from bzrlib import tests
 
 def load_tests(standard_tests, module, loader):
@@ -105,6 +108,12 @@
                             'd8:spam.mp3d6:author5:Alice6:lengthi100000eee')
 
     def test_dict_deepnested(self):
+        # The recursion here provokes CPython into emitting a warning on
+        # stderr, "maximum recursion depth exceeded in __subclasscheck__", due
+        # to running out of stack space while evaluating "except (...):" in
+        # _bencode_py.  This is harmless, so we temporarily override stderr to
+        # avoid distracting noise in the test output.
+        self.overrideAttr(sys, 'stderr', StringIO())
         self._run_check_error(RuntimeError, ("d0:" * 10000) + 'i1e' + ("e" * 10000))
 
     def test_malformed_dict(self):

